
Element
=======


.. automodule:: opendssdirect.Element
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Element.AllPropertyNames

    The names of all properties for the active DSS object.

.. function:: opendssdirect.Element.Name

    Full Name of Active DSS Object (general element or circuit element)

.. function:: opendssdirect.Element.NumProperties

    Number of Properties for the active DSS object.

